@@ -19,6 +19,14 @@ class UnauthorizedError(HEREError):
     """
 
 
+class AccessDeniedError(HEREError):
+
+    """Access Denied Error Type.
+
+    Indicates the request is not permitted with the credentials provided.
+    """
+
+
 class InvalidRequestError(HEREError):
 
     """Invalid Request Error Type.
